@@ -16,10 +16,10 @@ void mk_tempfile(stralloc *tmpf) {
   char host[256];
   char secbuf[11];
   char atto[TAIA_FMTFRAC];
+  char pidbuf[6];
   struct taia now;
   struct tai sec;
   unsigned long int pid = (unsigned long)getpid();
-  int b = 10;
 
   /* Get a microsecond timestamp with which to build a filename. */
   taia_now(&now);
@@ -28,18 +28,20 @@ void mk_tempfile(stralloc *tmpf) {
   /* Record the second timestamp on the string. */
   secbuf[fmt_uint64(secbuf,(uint64) sec.x - 4611686018427387904)] = '\0';
   if (!stralloc_cats(tmpf, secbuf)) die_nomem();
-  if (!stralloc_append(tmpf, ".")) die_nomem();
   
-  /* Record the millisecond timestamp + PID on the string. */
+  /* Append the microsecond timestamp to the string. */
+  if (!stralloc_cats(tmpf, ".M")) die_nomem();
   taia_fmtfrac(atto,&now);
-  atto[b--] = '\0';
-  for(; b>5 || pid>0; pid /= 10) {
-    atto[b--] = (char) ((pid % 10) + '0');
-  }
+  atto[6] = '\0'; /* truncate at microsecond */
   if (!stralloc_cats(tmpf, atto)) die_nomem();
-  if (!stralloc_append(tmpf, ".")) die_nomem();
+
+  /* Append the PID to the string. */
+  if (!stralloc_append(tmpf, "P")) die_nomem();
+  pidbuf[fmt_uint64(pidbuf, pid)] = '\0';
+  if (!stralloc_cats(tmpf, pidbuf)) die_nomem();
   
   /* Copy the hostname to the buffer. */
+  if (!stralloc_append(tmpf, ".")) die_nomem();
   get_hostname(host,sizeof(host));
   if (!stralloc_cats(tmpf, host)) die_nomem();
   if (!stralloc_0(tmpf)) die_nomem();
